Nanotubes

## 2.2 Nanotubes

To construct the carbon lattice the user has the option for either a finte-length nanotube or one that is periodic along the axial direction.

Figure 3: Nanotube construction options

### Finite tubes

Finite tubes are constructed as close to a user defined length as possible. This is done by constructing strips of basis points along the chiral vector ():

where is the carbon bond length of 1.421 . The incremented values () range from (0,0) to () and depends on:

After each new row of points, the origin is translated in the direction by . The current distance along the nanotube axis is then compared against the user defined length to determine if another strip should be added. The user defined length is inputted in the Calculations–Input options.

At each basis point at position , the positions of the carbon atoms ( and ) and dual lattice points () are given by:

### Periodic tubes

Periodic tubes are constructed using a user defined number of unit cells in the z direction. The periodic length of a nanotube of chirality () with unit cells is given by:

where the coefficients and have no common divisors except for unity and are given by:

During construction the carbon atoms and dual lattice points are constructed as for the finite tubes with the replacement of the user-defined length with the periodic length. After construction, any points surpassing the periodic length are removed.

The number of unit cells can also be found in the Calculations–Input options.

The periodic length can be found in the Information options tab. This will be required by simulation software if the nanotube is to be used in a periodic simulation.